==> irods-4.1.9.tar.gz: irods-4.1.9/iRODS/clients/icommands/src/iphymv.cpp <==
/*** Copyright (c), The Regents of the University of California            ***
 *** For more information please refer to files in the COPYRIGHT directory ***/
/*
 * iphymv - The irods physical move utility
 */

#include "rodsClient.h"
#include "parseCommandLine.h"
#include "rodsPath.h"
#include "phymvUtil.h"
#include "irods_client_api_table.hpp"
#include "irods_pack_table.hpp"

void usage();

int
main( int argc, char **argv ) {

    signal( SIGPIPE, SIG_IGN );

    int status;
    rodsEnv myEnv;
    rErrMsg_t errMsg;
    rcComm_t *conn;
    rodsArguments_t myRodsArgs;
    char *optStr;
    rodsPathInp_t rodsPathInp;


    optStr = "hMrvVp:n:R:S:";

    status = parseCmdLineOpt( argc, argv, optStr, 0, &myRodsArgs );

    if ( status < 0 ) {
        printf( "Use -h for help.\n" );
        exit( 1 );
    }

    if ( myRodsArgs.help == True ) {
        usage();
        exit( 0 );
    }

    if ( argc - optind <= 0 ) {
        rodsLog( LOG_ERROR, "iphymv: no input" );
        printf( "Use -h for help.\n" );
        exit( 2 );
    }

    status = getRodsEnv( &myEnv );

    if ( status < 0 ) {
        rodsLogError( LOG_ERROR, status, "main: getRodsEnv error. " );
        exit( 1 );
    }

    status = parseCmdLinePath( argc, argv, optind, &myEnv,
                               UNKNOWN_OBJ_T, NO_INPUT_T, 0, &rodsPathInp );

    if ( status < 0 ) {
        rodsLogError( LOG_ERROR, status, "main: parseCmdLinePath error. " );
        printf( "Use -h for help.\n" );
        exit( 1 );
    }

    // =-=-=-=-=-=-=-
    // initialize pluggable api table
    irods::api_entry_table&  api_tbl = irods::get_client_api_table();
    irods::pack_entry_table& pk_tbl  = irods::get_pack_table();
    init_api_table( api_tbl, pk_tbl );

    conn = rcConnect( myEnv.rodsHost, myEnv.rodsPort, myEnv.rodsUserName,
                      myEnv.rodsZone, 1, &errMsg );

    if ( conn == NULL ) {
        exit( 2 );
    }

    status = clientLogin( conn );
    if ( status != 0 ) {
        rcDisconnect( conn );
        exit( 7 );
    }

    status = phymvUtil( conn, &myEnv, &myRodsArgs, &rodsPathInp );

    printErrorStack( conn->rError );
    rcDisconnect( conn );

    if ( status < 0 ) {
        exit( 3 );
    }
    else {
        exit( 0 );
    }

}

void
usage() {

    char *msgs[] = {
        "Usage: iphymv [-hMrvV] [-n replNum] [-S srcResource]  [-R destResource] ",
        "dataObj|collection ... ",
        " ",
        "Physically move a file in iRODS to another storage resource.",
        " ",
        "Note that if the source copy has a checksum value associated with it,",
        "a checksum will be computed for the replicated copy and compared with",
        "the source value for verification.",
        " ",
        "Options are:",
        " -r  recursive - phymove the whole subtree",
        " -M  admin - admin user uses this option to phymove other users files",
        " -n  replNum  - the replica to be phymoved, typically not needed",
        " -S  srcResource - specifies the source resource for the move.",
        "     If specified, only copies stored in this resource will be moved.",
        "     Otherwise, one of the copy will be moved",
        " -R  destResource - specifies the destination resource for the move.",
        "     This can also be specified, in your environment or via a rule",
        "     set up by the administrator.",
        " -v  verbose",
        " -V  Very verbose",
        " -h  this help",
        ""
    };
    int i;
    for ( i = 0;; i++ ) {
        if ( strlen( msgs[i] ) == 0 ) {
            break;
        }
        printf( "%s\n", msgs[i] );
    }
    printReleaseInfo( "iphymv" );
}

==> irods-4.1.12.tar.gz: irods-4.1.12/iRODS/clients/icommands/src/iphymv.cpp <==
/*** Copyright (c), The Regents of the University of California            ***
 *** For more information please refer to files in the COPYRIGHT directory ***/
/*
 * iphymv - The irods physical move utility
 */

#include "rodsClient.h"
#include "parseCommandLine.h"
#include "rodsPath.h"
#include "phymvUtil.h"
#include "irods_client_api_table.hpp"
#include "irods_pack_table.hpp"

void usage();

int
main( int argc, char **argv ) {

    signal( SIGPIPE, SIG_IGN );

    int status;
    rodsEnv myEnv;
    rErrMsg_t errMsg;
    rcComm_t *conn;
    rodsArguments_t myRodsArgs;
    char *optStr;
    rodsPathInp_t rodsPathInp;


    optStr = "hMrvVp:n:R:S:";

    status = parseCmdLineOpt( argc, argv, optStr, 0, &myRodsArgs );

    if ( status < 0 ) {
        printf( "Use -h for help.\n" );
        exit( 1 );
    }

    if ( myRodsArgs.help == True ) {
        usage();
        exit( 0 );
    }

    if ( argc - optind <= 0 ) {
        rodsLog( LOG_ERROR, "iphymv: no input" );
        printf( "Use -h for help.\n" );
        exit( 2 );
    }

    status = getRodsEnv( &myEnv );

    if ( status < 0 ) {
        rodsLogError( LOG_ERROR, status, "main: getRodsEnv error. " );
        exit( 1 );
    }

    status = parseCmdLinePath( argc, argv, optind, &myEnv,
                               UNKNOWN_OBJ_T, NO_INPUT_T, 0, &rodsPathInp );

    if ( status < 0 ) {
        rodsLogError( LOG_ERROR, status, "main: parseCmdLinePath error. " );
        printf( "Use -h for help.\n" );
        exit( 1 );
    }

    // =-=-=-=-=-=-=-
    // initialize pluggable api table
    irods::api_entry_table&  api_tbl = irods::get_client_api_table();
    irods::pack_entry_table& pk_tbl  = irods::get_pack_table();
    init_api_table( api_tbl, pk_tbl );

    conn = rcConnect( myEnv.rodsHost, myEnv.rodsPort, myEnv.rodsUserName,
                      myEnv.rodsZone, 1, &errMsg );

    if ( conn == NULL ) {
        exit( 2 );
    }

    status = clientLogin( conn );
    if ( status != 0 ) {
        rcDisconnect( conn );
        exit( 7 );
    }

    status = phymvUtil( conn, &myEnv, &myRodsArgs, &rodsPathInp );

    printErrorStack( conn->rError );
    rcDisconnect( conn );

    if ( status < 0 ) {
        exit( 3 );
    }
    else {
        exit( 0 );
    }

}

void
usage() {

    char *msgs[] = {
        "Usage: iphymv [-hMrvV] [-n replNum] [-S srcResource]  [-R destResource] ",
        "dataObj|collection ... ",
        " ",
        "Physically move a file in iRODS to another storage resource.",
        " ",
        "Note that if the source copy has a checksum value associated with it,",
        "a checksum will be computed for the replicated copy and compared with",
        "the source value for verification.",
        " ",
        "Note that if the source or destination resource is within a hierarchy,",
        "a full resource hierarchy (semicolon delimited) must be specified:",
        "  iphymv -S demoResc -R 'pt1;r1;s1' /tempZone/home/alice/test.txt",
        " ",
        "Options are:",
        " -r  recursive - phymove the whole subtree",
        " -M  admin - admin user uses this option to phymove other users files",
        " -n  replNum  - the replica to be phymoved, typically not needed",
        " -S  srcResource - specifies the source resource for the move.",
        "     If specified, the replica stored on this resource will be moved.",
        "     Otherwise, any one of the replicas will be moved",
        " -R  destResource - specifies the destination resource for the move.",
        "     This can also be specified, in your environment or via a rule",
        "     set up by the administrator.",
        " -v  verbose",
        " -V  Very verbose",
        " -h  this help",
        ""
    };
    int i;
    for ( i = 0;; i++ ) {
        if ( strlen( msgs[i] ) == 0 ) {
            break;
        }
        printf( "%s\n", msgs[i] );
    }
    printReleaseInfo( "iphymv" );
}
